You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@chemistry.apache.org by fg...@apache.org on 2009/07/22 18:22:03 UTC

svn commit: r796781 - in /incubator/chemistry/trunk/chemistry: chemistry-api/src/main/java/org/apache/chemistry/ chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/ chemistry-atompub-server/src/main/java/org/apache/chemistry/ato...

Author: fguillaume
Date: Wed Jul 22 16:22:02 2009
New Revision: 796781

URL: http://svn.apache.org/viewvc?rev=796781&view=rev
Log:
CMIS-44: start of updates for 0.62

Modified:
    incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/Choice.java
    incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/ContentStreamPresence.java
    incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/JoinCapability.java
    incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/PropertyDefinition.java
    incubator/chemistry/trunk/chemistry/chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/APPPropertyDefinition.java
    incubator/chemistry/trunk/chemistry/chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/APPType.java
    incubator/chemistry/trunk/chemistry/chemistry-atompub-server/src/main/java/org/apache/chemistry/atompub/server/CMISTypesCollection.java
    incubator/chemistry/trunk/chemistry/chemistry-atompub-server/src/test/java/org/apache/chemistry/atompub/server/AtomPubServerTestCase.java
    incubator/chemistry/trunk/chemistry/chemistry-atompub/src/main/java/org/apache/chemistry/atompub/CMIS.java
    incubator/chemistry/trunk/chemistry/chemistry-commons/src/main/java/org/apache/chemistry/impl/simple/SimplePropertyDefinition.java
    incubator/chemistry/trunk/chemistry/chemistry-commons/src/main/java/org/apache/chemistry/impl/simple/SimpleType.java
    incubator/chemistry/trunk/chemistry/chemistry-commons/src/test/java/org/apache/chemistry/impl/simple/TestSimpleRepository.java
    incubator/chemistry/trunk/chemistry/chemistry-jcr/src/main/java/org/apache/chemistry/jcr/JcrObjectEntry.java
    incubator/chemistry/trunk/chemistry/chemistry-jcr/src/main/java/org/apache/chemistry/jcr/JcrPropertyDefinition.java
    incubator/chemistry/trunk/chemistry/chemistry-tests/src/main/java/org/apache/chemistry/test/BasicHelper.java

Modified: incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/Choice.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/Choice.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/Choice.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/Choice.java Wed Jul 22 16:22:02 2009
@@ -45,15 +45,6 @@
     Serializable getValue();
 
     /**
-     * The choice index.
-     * <p>
-     * The index provides guidance for the ordering of names when presented.
-     *
-     * @return the index
-     */
-    int getIndex();
-
-    /**
      * The sub-choices, if hierarchical.
      * <p>
      * The sub-choices are returnd ordered by index.

Modified: incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/ContentStreamPresence.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/ContentStreamPresence.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/ContentStreamPresence.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/ContentStreamPresence.java Wed Jul 22 16:22:02 2009
@@ -60,6 +60,14 @@
         return o;
     }
 
+    public static ContentStreamPresence get(String value, ContentStreamPresence def) {
+        ContentStreamPresence o = all.get(value);
+        if (o == null) {
+            o = def;
+        }
+        return o;
+    }
+
     @Override
     public String toString() {
         return value;

Modified: incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/JoinCapability.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/JoinCapability.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/JoinCapability.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/JoinCapability.java Wed Jul 22 16:22:02 2009
@@ -27,7 +27,7 @@
     /**
      * No join support.
      */
-    NO_JOIN("nojoin"),
+    NO_JOIN("none"),
 
     /**
      * Support inner join only.

Modified: incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/PropertyDefinition.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/PropertyDefinition.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/APPPropertyDefinition.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/APPPropertyDefinition.java Wed Jul 22 16:22:02 2009
@@ -159,10 +159,6 @@
         throw new UnsupportedOperationException("Not yet implemented");
     }
 
-    public String getEncoding() {
-        return (String) map.get("encoding");
-    }
-
     public boolean validates(Serializable value) {
         return validationError(value) == null;
     }

Modified: incubator/chemistry/trunk/chemistry/chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/APPType.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/APPType.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/APPType.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/APPType.java Wed Jul 22 16:22:02 2009
@@ -131,6 +131,11 @@
         return "true".equals(map.get(CMIS.VERSIONABLE.getLocalPart()));
     }
 
+    public ContentStreamPresence getContentStreamAllowed() {
+        return ContentStreamPresence.get(map.get(CMIS.CONTENT_STREAM_ALLOWED),
+                ContentStreamPresence.NOT_ALLOWED);
+    }
+
     public boolean isIncludedInSuperTypeQuery() {
         throw new UnsupportedOperationException("Not yet implemented");
     }
@@ -143,10 +148,6 @@
         throw new UnsupportedOperationException("Not yet implemented");
     }
 
-    public ContentStreamPresence getContentStreamAllowed() {
-        throw new UnsupportedOperationException("Not yet implemented");
-    }
-
     protected void loadPropertyDef() {
         if (propertyDefs == null) {
             APPType typeDef = (APPType) connection.getConnector().getType(

Modified: incubator/chemistry/trunk/chemistry/chemistry-atompub-server/src/main/java/org/apache/chemistry/atompub/server/CMISTypesCollection.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-atompub-server/src/main/java/org/apache/chemistry/atompub/server/CMISTypesCollection.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-atompub-server/src/main/java/org/apache/chemistry/atompub/server/CMISTypesCollection.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-atompub-server/src/main/java/org/apache/chemistry/atompub/server/CMISTypesCollection.java Wed Jul 22 16:22:02 2009
@@ -152,6 +152,8 @@
         el.setText(bool(type.isControllable()));
         el = factory.newElement(CMIS.VERSIONABLE, dt);
         el.setText(bool(type.isVersionable()));
+        el = factory.newElement(CMIS.CONTENT_STREAM_ALLOWED, dt);
+        el.setText(type.getContentStreamAllowed().toString()); // TODO null
         el = factory.newElement(CMIS.INCLUDED_IN_SUPERTYPE_QUERY, dt);
         el.setText(bool(type.isIncludedInSuperTypeQuery()));
         if ("true".equals(request.getParameter("includePropertyDefinitions"))) {
@@ -204,7 +206,7 @@
                 el = factory.newElement(CMIS.CARDINALITY, def);
                 el.setText(pd.isMultiValued() ? "multi" : "single");
                 el = factory.newElement(CMIS.UPDATABILITY, def);
-                el.setText(pd.getUpdatability().toString());
+                el.setText(pd.getUpdatability().toString()); // TODO null
                 el = factory.newElement(CMIS.INHERITED, def);
                 el.setText(pd.isInherited() ? "true" : "false");
                 el = factory.newElement(CMIS.REQUIRED, def);

Modified: incubator/chemistry/trunk/chemistry/chemistry-atompub-server/src/test/java/org/apache/chemistry/atompub/server/AtomPubServerTestCase.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-atompub-server/src/test/java/org/apache/chemistry/atompub/server/AtomPubServerTestCase.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-atompub-server/src/test/java/org/apache/chemistry/atompub/server/AtomPubServerTestCase.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-atompub-server/src/test/java/org/apache/chemistry/atompub/server/AtomPubServerTestCase.java Wed Jul 22 16:22:02 2009
@@ -95,16 +95,15 @@
         PropertyDefinition p1 = new SimplePropertyDefinition("title",
                 "def:title", "Title", "", false, PropertyType.STRING, false,
                 null, false, false, "", Updatability.READ_WRITE, true, true, 0,
-                null, null, -1, null, null);
+                null, null, -1, null);
         PropertyDefinition p2 = new SimplePropertyDefinition("description",
                 "def:description", "Description", "", false,
                 PropertyType.STRING, false, null, false, false, "",
-                Updatability.READ_WRITE, true, true, 0, null, null, -1, null,
-                null);
+                Updatability.READ_WRITE, true, true, 0, null, null, -1, null);
         PropertyDefinition p3 = new SimplePropertyDefinition("date",
                 "def:date", "Date", "", false, PropertyType.DATETIME, false,
                 null, false, false, null, Updatability.READ_WRITE, true, true,
-                0, null, null, -1, null, null);
+                0, null, null, -1, null);
         SimpleType dt = new SimpleType("doc", "document", "Doc", "My Doc Type",
                 BaseType.DOCUMENT, "", true, true, true, true, true, true,
                 ContentStreamPresence.ALLOWED, null, null, Arrays.asList(p1,

Modified: incubator/chemistry/trunk/chemistry/chemistry-atompub/src/main/java/org/apache/chemistry/atompub/CMIS.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-atompub/src/main/java/org/apache/chemistry/atompub/CMIS.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-atompub/src/main/java/org/apache/chemistry/atompub/CMIS.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-atompub/src/main/java/org/apache/chemistry/atompub/CMIS.java Wed Jul 22 16:22:02 2009
@@ -113,6 +113,8 @@
 
     public static final QName VERSIONABLE = CMISName("versionable");
 
+    public static final QName CONTENT_STREAM_ALLOWED = CMISName("contentStreamAllowed");
+
     public static final QName INCLUDED_IN_SUPERTYPE_QUERY = CMISName("includedInSupertypeQuery");
 
     public static final QName PROPERTY_STRING_DEFINITION = CMISName("propertyStringDefinition");

Modified: incubator/chemistry/trunk/chemistry/chemistry-commons/src/main/java/org/apache/chemistry/impl/simple/SimplePropertyDefinition.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-commons/src/main/java/org/apache/chemistry/impl/simple/SimplePropertyDefinition.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-commons/src/main/java/org/apache/chemistry/impl/simple/SimplePropertyDefinition.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-commons/src/main/java/org/apache/chemistry/impl/simple/SimplePropertyDefinition.java Wed Jul 22 16:22:02 2009
@@ -59,23 +59,21 @@
 
     private final int precision;
 
-    private final Integer minValue;
+    private final Number minValue;
 
-    private final Integer maxValue;
+    private final Number maxValue;
 
     private final int maxLength;
 
     private final URI schemaURI;
 
-    private final String encoding;
-
     public SimplePropertyDefinition(String name, String id, String displayName,
             String description, boolean inherited, PropertyType type,
             boolean multiValued, List<Choice> choices, boolean openChoice,
             boolean required, Serializable defaultValue,
             Updatability updatability, boolean queryable, boolean orderable,
             int precision, Integer minValue, Integer maxValue, int maxLength,
-            URI schemaURI, String encoding) {
+            URI schemaURI) {
         super();
         if (name.equals(SimpleProperty.CONTENT_BYTES_KEY)) {
             throw new IllegalArgumentException(SimpleProperty.CONTENT_BYTES_KEY
@@ -101,7 +99,6 @@
         this.maxValue = maxValue;
         this.maxLength = maxLength;
         this.schemaURI = schemaURI;
-        this.encoding = encoding;
     }
 
     public String getName() {
@@ -164,11 +161,11 @@
         return precision;
     }
 
-    public Integer getMinValue() {
+    public Number getMinValue() {
         return minValue;
     }
 
-    public Integer getMaxValue() {
+    public Number getMaxValue() {
         return maxValue;
     }
 
@@ -180,10 +177,6 @@
         return schemaURI;
     }
 
-    public String getEncoding() {
-        return encoding;
-    }
-
     public boolean validates(Serializable value) {
         return validationError(value) == null;
     }

Modified: incubator/chemistry/trunk/chemistry/chemistry-commons/src/main/java/org/apache/chemistry/impl/simple/SimpleType.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-commons/src/main/java/org/apache/chemistry/impl/simple/SimpleType.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-commons/src/main/java/org/apache/chemistry/impl/simple/SimpleType.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-commons/src/main/java/org/apache/chemistry/impl/simple/SimpleType.java Wed Jul 22 16:22:02 2009
@@ -37,156 +37,156 @@
     public static final SimplePropertyDefinition PROP_ID = new SimplePropertyDefinition(
             Property.ID, "def:id", "Id", "", false, PropertyType.ID, false,
             null, false, true, null, Updatability.READ_ONLY, true, true, 0,
-            null, null, -1, null, null);
+            null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_URI = new SimplePropertyDefinition(
             Property.URI, "def:uri", "URI", "", false, PropertyType.URI, false,
             null, false, false, null, Updatability.READ_ONLY, true, true, 0,
-            null, null, -1, null, null);
+            null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_TYPE_ID = new SimplePropertyDefinition(
             Property.TYPE_ID, "def:typeid", "Type ID", "", false,
             PropertyType.ID, false, null, false, true, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_CREATED_BY = new SimplePropertyDefinition(
             Property.CREATED_BY, "def:createdby", "Created By", "", false,
             PropertyType.STRING, false, null, false, true, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_CREATION_DATE = new SimplePropertyDefinition(
             Property.CREATION_DATE, "def:creationdate", "Creation Date", "",
             false, PropertyType.DATETIME, false, null, false, true, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_LAST_MODIFIED_BY = new SimplePropertyDefinition(
             Property.LAST_MODIFIED_BY, "def:lastmodifiedby",
             "Last Modified By", "", false, PropertyType.STRING, false, null,
             false, true, null, Updatability.READ_ONLY, true, true, 0, null,
-            null, -1, null, null);
+            null, -1, null);
 
     public static final SimplePropertyDefinition PROP_LAST_MODIFICATION_DATE = new SimplePropertyDefinition(
             Property.LAST_MODIFICATION_DATE, "def:lastmodificationdate",
             "Last Modification Date", "", false, PropertyType.DATETIME, false,
             null, false, true, null, Updatability.READ_ONLY, true, true, 0,
-            null, null, -1, null, null);
+            null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_CHANGE_TOKEN = new SimplePropertyDefinition(
             Property.CHANGE_TOKEN, "def:changetoken", "Change Token", "",
             false, PropertyType.STRING, false, null, false, false, null,
-            Updatability.READ_WRITE, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_WRITE, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_NAME = new SimplePropertyDefinition(
             Property.NAME, "def:name", "Name", "", false, PropertyType.STRING,
             false, null, false, true, null, Updatability.READ_WRITE, true,
-            true, 0, null, null, -1, null, null);
+            true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_IS_LATEST_VERSION = new SimplePropertyDefinition(
             Property.IS_LATEST_VERSION, "def:islatestversion",
             "Is Latest Version", "", false, PropertyType.BOOLEAN, false, null,
             false, true, null, Updatability.READ_ONLY, true, true, 0, null,
-            null, -1, null, null);
+            null, -1, null);
 
     public static final SimplePropertyDefinition PROP_IS_MAJOR_VERSION = new SimplePropertyDefinition(
             Property.IS_MAJOR_VERSION, "def:ismajorversion",
             "Is Major Version", "", false, PropertyType.BOOLEAN, false, null,
             false, false, null, Updatability.READ_ONLY, true, true, 0, null,
-            null, -1, null, null);
+            null, -1, null);
 
     public static final SimplePropertyDefinition PROP_IS_LATEST_MAJOR_VERSION = new SimplePropertyDefinition(
             Property.IS_LATEST_MAJOR_VERSION, "def:islatestmajorversion",
             "Is Latest Major Version", "", false, PropertyType.BOOLEAN, false,
             null, false, true, null, Updatability.READ_ONLY, true, true, 0,
-            null, null, -1, null, null);
+            null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_VERSION_LABEL = new SimplePropertyDefinition(
             Property.VERSION_LABEL, "def:versionlabel", "Version Label", "",
             false, PropertyType.STRING, false, null, false, true, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_VERSION_SERIES_ID = new SimplePropertyDefinition(
             Property.VERSION_SERIES_ID, "def:versionseriesid",
             "Version Series ID", "", false, PropertyType.ID, false, null,
             false, true, null, Updatability.READ_ONLY, true, true, 0, null,
-            null, -1, null, null);
+            null, -1, null);
 
     public static final SimplePropertyDefinition PROP_IS_VERSION_SERIES_CHECKED_OUT = new SimplePropertyDefinition(
             Property.IS_VERSION_SERIES_CHECKED_OUT,
             "def:isversionseriescheckedout", "Is Version Series Checked Out",
             "", false, PropertyType.BOOLEAN, false, null, false, true, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_VERSION_SERIES_CHECKED_OUT_BY = new SimplePropertyDefinition(
             Property.VERSION_SERIES_CHECKED_OUT_BY,
             "def:versionseriescheckedoutby", "Version Series Checked Out By",
             "", false, PropertyType.STRING, false, null, false, false, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_VERSION_SERIES_CHECKED_OUT_ID = new SimplePropertyDefinition(
             Property.VERSION_SERIES_CHECKED_OUT_ID,
             "def:versionseriescheckedoutid", "Version Series Checked Out Id",
             "", false, PropertyType.ID, false, null, false, false, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_CHECKIN_COMMENT = new SimplePropertyDefinition(
             Property.CHECKIN_COMMENT, "def:checkincomment", "Checkin Comment",
             "", false, PropertyType.STRING, false, null, false, false, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_CONTENT_STREAM_LENGTH = new SimplePropertyDefinition(
             Property.CONTENT_STREAM_LENGTH, "def:contentstreamlength",
             "Content Stream Length", "", false, PropertyType.INTEGER, false,
             null, false, false, null, Updatability.READ_ONLY, true, true, 0,
-            null, null, -1, null, null);
+            null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_CONTENT_STREAM_MIME_TYPE = new SimplePropertyDefinition(
             Property.CONTENT_STREAM_MIME_TYPE, "def:contentstreammimetype",
             "Content Stream MIME Type", "", false, PropertyType.STRING, false,
             null, false, false, null, Updatability.READ_ONLY, true, true, 0,
-            null, null, -1, null, null);
+            null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_CONTENT_STREAM_FILENAME = new SimplePropertyDefinition(
             Property.CONTENT_STREAM_FILENAME, "def:contentstreamfilename",
             "Content Stream Filename", "", false, PropertyType.STRING, false,
             null, false, false, null, Updatability.READ_WRITE, true, true, 0,
-            null, null, -1, null, null);
+            null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_CONTENT_STREAM_URI = new SimplePropertyDefinition(
             Property.CONTENT_STREAM_URI, "def:contentstreamuri",
             "Content Stream URI", "", false, PropertyType.URI, false, null,
             false, false, null, Updatability.READ_ONLY, true, true, 0, null,
-            null, -1, null, null);
+            null, -1, null);
 
     public static final SimplePropertyDefinition PROP_PARENT_ID = new SimplePropertyDefinition(
             Property.PARENT_ID, "def:parentid", "Parent Id", "", false,
             PropertyType.ID, false, null, false, true, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_ALLOWED_CHILD_OBJECT_TYPE_IDS = new SimplePropertyDefinition(
             Property.ALLOWED_CHILD_OBJECT_TYPE_IDS,
             "def:allowedchildobjecttypeids", "Allowed Child Object Type Ids",
             "", false, PropertyType.ID, true, null, false, false, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_SOURCE_ID = new SimplePropertyDefinition(
             Property.SOURCE_ID, "def:sourceid", "Source Id", "", false,
             PropertyType.ID, false, null, false, true, null,
-            Updatability.READ_WRITE, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_WRITE, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_TARGET_ID = new SimplePropertyDefinition(
             Property.TARGET_ID, "def:targetid", "Target Id", "", false,
             PropertyType.ID, false, null, false, true, null,
-            Updatability.READ_WRITE, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_WRITE, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_POLICY_NAME = new SimplePropertyDefinition(
             Property.POLICY_NAME, "def:policyname", "Policy Name", "", false,
             PropertyType.STRING, false, null, false, true, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public static final SimplePropertyDefinition PROP_POLICY_TEXT = new SimplePropertyDefinition(
             Property.POLICY_TEXT, "def:policytext", "Policy Text", "", false,
             PropertyType.STRING, false, null, false, true, null,
-            Updatability.READ_WRITE, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_WRITE, true, true, 0, null, null, -1, null);
 
     private static final PropertyDefinition[] PROPS_COMMON = {
             PROP_ID, //

Modified: incubator/chemistry/trunk/chemistry/chemistry-commons/src/test/java/org/apache/chemistry/impl/simple/TestSimpleRepository.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-commons/src/test/java/org/apache/chemistry/impl/simple/TestSimpleRepository.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-commons/src/test/java/org/apache/chemistry/impl/simple/TestSimpleRepository.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-commons/src/test/java/org/apache/chemistry/impl/simple/TestSimpleRepository.java Wed Jul 22 16:22:02 2009
@@ -52,16 +52,15 @@
         PropertyDefinition d1 = new SimplePropertyDefinition("title",
                 "def:title", "Title", "", false, PropertyType.STRING, false,
                 null, false, false, "", Updatability.READ_WRITE, true, true, 0,
-                null, null, -1, null, null);
+                null, null, -1, null);
         PropertyDefinition d2 = new SimplePropertyDefinition("description",
                 "def:description", "Description", "", false,
                 PropertyType.STRING, false, null, false, false, "",
-                Updatability.READ_WRITE, true, true, 0, null, null, -1, null,
-                null);
+                Updatability.READ_WRITE, true, true, 0, null, null, -1, null);
         PropertyDefinition d3 = new SimplePropertyDefinition("date",
                 "def:date", "Date", "", false, PropertyType.DATETIME, false,
                 null, false, false, null, Updatability.READ_WRITE, true, true,
-                0, null, null, -1, null, null);
+                0, null, null, -1, null);
         SimpleType mt1 = new SimpleType("doc", null, "Doc", "My Doc Type",
                 BaseType.DOCUMENT, "", true, true, true, true, true, true,
                 ContentStreamPresence.ALLOWED, null, null, Arrays.asList(d1,

Modified: incubator/chemistry/trunk/chemistry/chemistry-jcr/src/main/java/org/apache/chemistry/jcr/JcrObjectEntry.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-jcr/src/main/java/org/apache/chemistry/jcr/JcrObjectEntry.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-jcr/src/main/java/org/apache/chemistry/jcr/JcrObjectEntry.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-jcr/src/main/java/org/apache/chemistry/jcr/JcrObjectEntry.java Wed Jul 22 16:22:02 2009
@@ -266,7 +266,7 @@
     private static final SimplePropertyDefinition PROP_TYPE_ID = new SimplePropertyDefinition(
             Property.TYPE_ID, "def:typeid", "Type ID", "", false,
             PropertyType.ID, false, null, false, true, null,
-            Updatability.READ_ONLY, true, true, 0, null, null, -1, null, null);
+            Updatability.READ_ONLY, true, true, 0, null, null, -1, null);
 
     public Map<String, Property> getProperties() {
         Map<String, Property> properties = new HashMap<String, Property>();

Modified: incubator/chemistry/trunk/chemistry/chemistry-jcr/src/main/java/org/apache/chemistry/jcr/JcrPropertyDefinition.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-jcr/src/main/java/org/apache/chemistry/jcr/JcrPropertyDefinition.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-jcr/src/main/java/org/apache/chemistry/jcr/JcrPropertyDefinition.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-jcr/src/main/java/org/apache/chemistry/jcr/JcrPropertyDefinition.java Wed Jul 22 16:22:02 2009
@@ -51,11 +51,6 @@
         return propDef.getName();
     }
 
-    public String getEncoding() {
-        // TODO Auto-generated method stub
-        return null;
-    }
-
     public String getId() {
         return propDef.getName();
     }

Modified: incubator/chemistry/trunk/chemistry/chemistry-tests/src/main/java/org/apache/chemistry/test/BasicHelper.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-tests/src/main/java/org/apache/chemistry/test/BasicHelper.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================
--- incubator/chemistry/trunk/chemistry/chemistry-tests/src/main/java/org/apache/chemistry/test/BasicHelper.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-tests/src/main/java/org/apache/chemistry/test/BasicHelper.java Wed Jul 22 16:22:02 2009
@@ -50,16 +50,15 @@
         PropertyDefinition p1 = new SimplePropertyDefinition("title",
                 "def:title", "Title", "", false, PropertyType.STRING, false,
                 null, false, false, "(no title)", Updatability.READ_WRITE,
-                true, true, 0, null, null, -1, null, null);
+                true, true, 0, null, null, -1, null);
         PropertyDefinition p2 = new SimplePropertyDefinition("description",
                 "def:description", "Description", "", false,
                 PropertyType.STRING, false, null, false, false, "",
-                Updatability.READ_WRITE, true, true, 0, null, null, -1, null,
-                null);
+                Updatability.READ_WRITE, true, true, 0, null, null, -1, null);
         PropertyDefinition p3 = new SimplePropertyDefinition("date",
                 "def:date", "Date", "", false, PropertyType.DATETIME, false,
                 null, false, false, null, Updatability.READ_WRITE, true, true,
-                0, null, null, -1, null, null);
+                0, null, null, -1, null);
         SimpleType dt = new SimpleType("doc", "document", "Doc", "My Doc Type",
                 BaseType.DOCUMENT, "", true, true, true, true, true, true,
                 ContentStreamPresence.ALLOWED, null, null, Arrays.asList(p1,
--- incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/PropertyDefinition.java (original)
+++ incubator/chemistry/trunk/chemistry/chemistry-api/src/main/java/org/apache/chemistry/PropertyDefinition.java Wed Jul 22 16:22:02 2009
@@ -17,6 +17,7 @@
 package org.apache.chemistry;
 
 import java.io.Serializable;
+import java.math.BigDecimal;
 import java.net.URI;
 import java.util.List;
 
@@ -205,23 +206,29 @@
      * This is the precision in bits supported for this property (32 or 64
      * currently).
      *
-     * @return the precisions
+     * @return the precision
      */
     int getPrecision();
 
     /**
      * The minimum value for this integer property.
      *
      * @return the minimum value, or {@code null} if none is provided
      */
-    Integer getMinValue();
+    Number getMinValue();
 
     /**
      * The maximum value for this integer property.
      *
      * @return the maximum value, or {@code null} if none is provided
      */
-    Integer getMaxValue();
+    Number getMaxValue();
 
     /**
      * The maximum length of this string property.
@@ -241,16 +248,6 @@
     URI getSchemaURI();
 
     /**
-     * The encoding for this XML property.
-     * <p>
-     * This specifies the encoding used for the property value (e.g. UTF-8,
-     * etc.).
-     *
-     * @return the encoding for this property
-     */
-    String getEncoding();
-
-    /**
      * Checks if a value can be set in this property.
      *
      * @param value the candidate value
@@ -205,23 +206,29 @@
 
     /**
-     * The minimum value for this integer property.
+     * The minimum value for this property.
+     * <p>
+     * It will be an {@link Integer} for an integer property, and a
+     * {@link BigDecimal} for a decimal property.
      *
      * @return the minimum value, or {@code null} if none is provided
@@ -205,23 +206,29 @@
 
     /**
-     * The maximum value for this integer property.
+     * The maximum value for this property.
+     * <p>
+     * It will be an {@link Integer} for an integer property, and a
+     * {@link BigDecimal} for a decimal property.
      *
      * @return the maximum value, or {@code null} if none is provided

Modified: incubator/chemistry/trunk/chemistry/chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/APPPropertyDefinition.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/trunk/chemistry/chemistry-atompub-client/src/main/java/org/apache/chemistry/atompub/client/APPPropertyDefinition.java?rev=796781&r1=796780&r2=796781&view=diff
==============================================================================